@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 from multiprocessing import Pool
 import os
 import random
@@ -5,7 +9,7 @@ import shutil
 import glob
 import unittest
 import time
-from fireworks.core.firework import FireWork, Workflow
+from fireworks.core.firework import Firework, Workflow
 from fireworks.core.fworker import FWorker
 from fireworks.core.launchpad import LaunchPad, WFLock
 from fireworks.core.rocket_launcher import launch_rocket, rapidfire
@@ -76,7 +80,7 @@ class MongoTests(unittest.TestCase):
     def test_basic_fw(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'",
                                     {'store_stdout': True})
-        fw = FireWork(test1)
+        fw = Firework(test1)
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(self.lp.get_launch_by_id(1).action.stored_data[
@@ -87,7 +91,7 @@ class MongoTests(unittest.TestCase):
                                     {'store_stdout': True})
         test2 = ScriptTask.from_str("python -c 'print(\"test2\")'",
                                     {'store_stdout': True})
-        fw = FireWork([test1, test2])
+        fw = Firework([test1, test2])
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(
@@ -100,10 +104,10 @@ class MongoTests(unittest.TestCase):
         dest2 = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'temp_file.txt')
         self._teardown([dest1, dest2])
         try:
-            # create the FireWork consisting of multiple tasks
+            # create the Firework consisting of multiple tasks
             firetask1 = TemplateWriterTask({'context': {'opt1': 5.0, 'opt2': 'fast method'}, 'template_file': 'simple_template.txt', 'output_file': dest1})
             firetask2 = FileTransferTask({'files': [{'src': dest1, 'dest': dest2}], 'mode': 'copy'})
-            fw = FireWork([firetask1, firetask2])
+            fw = Firework([firetask1, firetask2])
 
             # store workflow and launch it locally, single shot
             self.lp.add_wf(fw)
@@ -127,7 +131,7 @@ class MongoTests(unittest.TestCase):
                                         {'store_stdout': True})
 
             bg_task1 = BackgroundTask(FileWriteTask({'files_to_write': [{'filename': dest1, 'contents': 'hello'}]}), num_launches=1, run_on_finish=True)
-            fw = FireWork(test1, spec={'_background_tasks': [bg_task1]})
+            fw = Firework(test1, spec={'_background_tasks': [bg_task1]})
             self.lp.add_wf(fw)
             launch_rocket(self.lp, self.fworker)
 
@@ -138,7 +142,7 @@ class MongoTests(unittest.TestCase):
             self._teardown([dest1])
 
     def test_add_fw(self):
-        fw = FireWork(AdditionTask(), {'input_array': [5, 7]})
+        fw = Firework(AdditionTask(), {'input_array': [5, 7]})
         self.lp.add_wf(fw)
         rapidfire(self.lp, self.fworker, m_dir=MODULE_DIR)
         self.assertEqual(self.lp.get_launch_by_id(1).action.stored_data['sum'], 12)
@@ -148,8 +152,8 @@ class MongoTests(unittest.TestCase):
                                     {'store_stdout': True})
         test2 = ScriptTask.from_str("python -c 'print(\"test2\")'",
                                     {'store_stdout': True})
-        fw1 = FireWork(test1, fw_id=-1)
-        fw2 = FireWork(test2, fw_id=-2)
+        fw1 = Firework(test1, fw_id=-1)
+        fw2 = Firework(test2, fw_id=-2)
         wf = Workflow([fw1, fw2], {-1: -2})
         self.lp.add_wf(wf)
         launch_rocket(self.lp, self.fworker)
@@ -161,7 +165,7 @@ class MongoTests(unittest.TestCase):
 
     def test_fibadder(self):
         fib = FibonacciAdderTask()
-        fw = FireWork(fib, {'smaller': 0, 'larger': 1, 'stop_point': 3})
+        fw = Firework(fib, {'smaller': 0, 'larger': 1, 'stop_point': 3})
         self.lp.add_wf(fw)
         rapidfire(self.lp, self.fworker, m_dir=MODULE_DIR)
 
@@ -172,11 +176,11 @@ class MongoTests(unittest.TestCase):
 
     def test_parallel_fibadder(self):
         # this is really testing to see if a Workflow can handle multiple FWs updating it at once
-        parent = FireWork(ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True}))
-        fib1 = FireWork(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
-        fib2 = FireWork(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
-        fib3 = FireWork(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
-        fib4 = FireWork(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
+        parent = Firework(ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True}))
+        fib1 = Firework(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
+        fib2 = Firework(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
+        fib3 = Firework(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
+        fib4 = Firework(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, parents=[parent])
         wf = Workflow([parent, fib1, fib2, fib3, fib4])
         self.lp.add_wf(wf)
 
@@ -187,7 +191,7 @@ class MongoTests(unittest.TestCase):
 
     def test_fworkerenv(self):
         t = DummyTask()
-        fw = FireWork(t)
+        fw = Firework(t)
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(self.lp.get_launch_by_id(1).action.stored_data[
@@ -205,8 +209,8 @@ class MongoTests(unittest.TestCase):
 
         spec = {'_category': 'dummy_category'}
 
-        fw1 = FireWork(task1, fw_id=1, name='Task 1', spec=spec)
-        fw2 = FireWork(task2, fw_id=2, name='Task 2', spec=spec)
+        fw1 = Firework(task1, fw_id=1, name='Task 1', spec=spec)
+        fw2 = Firework(task2, fw_id=2, name='Task 2', spec=spec)
 
         self.lp.add_wf(Workflow([fw1, fw2]))
 
@@ -215,7 +219,7 @@ class MongoTests(unittest.TestCase):
 
     def test_delete_fw(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True})
-        fw = FireWork(test1)
+        fw = Firework(test1)
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
         self.assertEqual(self.lp.get_launch_by_id(1).action.stored_data[
@@ -227,7 +231,7 @@ class MongoTests(unittest.TestCase):
 
     def test_duplicate_delete_fw(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True})
-        fw = FireWork(test1, {"_dupefinder": DupeFinderExact()})
+        fw = Firework(test1, {"_dupefinder": DupeFinderExact()})
         self.lp.add_wf(fw)
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
@@ -240,7 +244,7 @@ class MongoTests(unittest.TestCase):
 
     def test_dupefinder(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True})
-        fw = FireWork(test1, {"_dupefinder": DupeFinderExact()})
+        fw = Firework(test1, {"_dupefinder": DupeFinderExact()})
         self.lp.add_wf(fw)
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
@@ -250,7 +254,7 @@ class MongoTests(unittest.TestCase):
 
     def test_force_lock_removal(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True})
-        fw = FireWork(test1, {"_dupefinder": DupeFinderExact()}, fw_id=1)
+        fw = Firework(test1, {"_dupefinder": DupeFinderExact()}, fw_id=1)
         self.lp.add_wf(fw)
         self.assertEqual(WFLOCK_EXPIRATION_KILL, True)
         # add a manual lock
@@ -260,7 +264,7 @@ class MongoTests(unittest.TestCase):
 
     def test_fizzle(self):
         p = PyTask(func="fireworks.tests.mongo_tests.throw_error", args=["Testing; this error is normal."])
-        fw = FireWork(p)
+        fw = Firework(p)
         self.lp.add_wf(fw)
         self.assertTrue(launch_rocket(self.lp, self.fworker))
         self.assertEqual(self.lp.get_fw_by_id(1).state, 'FIZZLED')
@@ -268,21 +272,21 @@ class MongoTests(unittest.TestCase):
 
     def test_defuse(self):
         p = PyTask(func="fireworks.tests.mongo_tests.throw_error", args=["This should not happen"])
-        fw = FireWork(p)
+        fw = Firework(p)
         self.lp.add_wf(fw)
         self.lp.defuse_fw(fw.fw_id)
         self.assertFalse(launch_rocket(self.lp, self.fworker))
 
     def test_archive(self):
         p = PyTask(func="fireworks.tests.mongo_tests.throw_error", args=["This should not happen"])
-        fw = FireWork(p)
+        fw = Firework(p)
         self.lp.add_wf(fw)
         self.lp.archive_wf(fw.fw_id)
         self.assertFalse(launch_rocket(self.lp, self.fworker))
 
     def test_stats(self):
         test1 = ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True})
-        fw = FireWork(test1)
+        fw = Firework(test1)
         self.lp.add_wf(fw)
         self.lp.add_wf(fw)
         launch_rocket(self.lp, self.fworker)
@@ -311,4 +315,4 @@ class MongoTests(unittest.TestCase):
             cls.lp.connection.drop_database(TESTDB_NAME)
 
 if __name__ == "__main__":
-    unittest.main()
\ No newline at end of file
+    unittest.main()
