@@ -21,6 +21,6 @@ class AdditionTask(FireTaskBase):
         input_array = fw_spec['input_array']
         m_sum = sum(input_array)
 
-        print "The sum of {} is: {}".format(input_array, m_sum)
+        print("The sum of {} is: {}".format(input_array, m_sum))
 
         return FWAction(stored_data={'sum': m_sum})
